Scope

Struct Scope 

pub struct Scope { /* private fields */ }
Supports creation of scoped metrics.

Scopes may be cloned without copying the underlying metrics registry.

Labels may be attached to the scope so that all metrics created by the Scope are labeled.

Implementations

Source

impl Scope

pub fn labels(&self) -> &BTreeMap<&'static str, String>

Accesses scoping labels.

pub fn labeled<D: Display>(self, k: &'static str, v: D) -> Self

Adds a label into scope (potentially overwriting).

pub fn prefixed(self, value: &'static str) -> Self

Appends a prefix to the current scope.

pub fn counter(&self, name: &'static str) -> Counter

Creates a Counter with the given name.

pub fn gauge(&self, name: &'static str) -> Gauge

Creates a Gauge with the given name.

pub fn stat(&self, name: &'static str) -> Stat

Creates a Stat with the given name.

The underlying histogram is automatically resized as values are added.

pub fn timer_us(&self, name: &'static str) -> Timer

pub fn timer_ms(&self, name: &'static str) -> Timer

pub fn stat_with_bounds(&self, name: &'static str, low: u64, high: u64) -> Stat

Creates a Stat with the given name and histogram paramters.